@@ -41,7 +41,11 @@ from datamodel_code_generator import (
     enable_debug_message,
     generate,
 )
-from datamodel_code_generator.format import PythonVersion, is_supported_in_black
+from datamodel_code_generator.format import (
+    PythonVersion,
+    black_find_project_root,
+    is_supported_in_black,
+)
 from datamodel_code_generator.parser import LiteralType
 from datamodel_code_generator.reference import is_url
 from datamodel_code_generator.types import StrictTypes
@@ -79,6 +83,14 @@ arg_parser.add_argument(
     metavar='HTTP_HEADER',
     help='Set headers in HTTP requests to the remote host. (example: "Authorization: Basic dXNlcjpwYXNz")',
 )
+
+arg_parser.add_argument(
+    '--http-ignore-tls',
+    help="Disable verification of the remote host's TLS certificate",
+    action='store_true',
+    default=False,
+)
+
 arg_parser.add_argument(
     '--input-file-type',
     help='Input file type (default: auto)',
@@ -405,6 +417,7 @@ class Config(BaseModel):
     wrap_string_literal: Optional[bool] = None
     use_title_as_name: bool = False
     http_headers: Optional[Sequence[Tuple[str, str]]] = None
+    http_ignore_tls: bool = False
     use_annotated: bool = False
     use_non_positive_negative_number_constrained_types: bool = False
 
@@ -435,7 +448,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
         print(version)
         exit(0)
 
-    root = black.find_project_root((Path().resolve(),))
+    root = black_find_project_root((Path().resolve(),))
     pyproject_toml_path = root / "pyproject.toml"
     if pyproject_toml_path.is_file():
         pyproject_toml: Dict[str, Any] = {
@@ -535,6 +548,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             wrap_string_literal=config.wrap_string_literal,
             use_title_as_name=config.use_title_as_name,
             http_headers=config.http_headers,
+            http_ignore_tls=config.http_ignore_tls,
             use_annotated=config.use_annotated,
             use_non_positive_negative_number_constrained_types=config.use_non_positive_negative_number_constrained_types,
         )
