@@ -7,8 +7,12 @@ IMPORT_CONDECIMAL = Import.from_full_path('pydantic.condecimal')
 IMPORT_CONBYTES = Import.from_full_path('pydantic.conbytes')
 IMPORT_POSITIVE_INT = Import.from_full_path('pydantic.PositiveInt')
 IMPORT_NEGATIVE_INT = Import.from_full_path('pydantic.NegativeInt')
+IMPORT_NON_POSITIVE_INT = Import.from_full_path('pydantic.NonPositiveInt')
+IMPORT_NON_NEGATIVE_INT = Import.from_full_path('pydantic.NonNegativeInt')
 IMPORT_POSITIVE_FLOAT = Import.from_full_path('pydantic.PositiveFloat')
 IMPORT_NEGATIVE_FLOAT = Import.from_full_path('pydantic.NegativeFloat')
+IMPORT_NON_NEGATIVE_FLOAT = Import.from_full_path('pydantic.NonNegativeFloat')
+IMPORT_NON_POSITIVE_FLOAT = Import.from_full_path('pydantic.NonPositiveFloat')
 IMPORT_SECRET_STR = Import.from_full_path('pydantic.SecretStr')
 IMPORT_EMAIL_STR = Import.from_full_path('pydantic.EmailStr')
 IMPORT_UUID1 = Import.from_full_path('pydantic.UUID1')
