@@ -22,6 +22,10 @@ from datamodel_code_generator.model.pydantic.imports import (
     IMPORT_IPV6ADDRESS,
     IMPORT_NEGATIVE_FLOAT,
     IMPORT_NEGATIVE_INT,
+    IMPORT_NON_NEGATIVE_FLOAT,
+    IMPORT_NON_NEGATIVE_INT,
+    IMPORT_NON_POSITIVE_FLOAT,
+    IMPORT_NON_POSITIVE_INT,
     IMPORT_POSITIVE_FLOAT,
     IMPORT_POSITIVE_INT,
     IMPORT_SECRET_STR,
@@ -152,12 +156,14 @@ class DataTypeManager(_DataTypeManager):
         use_standard_collections: bool = False,
         use_generic_container_types: bool = False,
         strict_types: Optional[Sequence[StrictTypes]] = None,
+        use_non_positive_negative_number_constrained_types: bool = False,
     ):
         super().__init__(
             python_version,
             use_standard_collections,
             use_generic_container_types,
             strict_types,
+            use_non_positive_negative_number_constrained_types,
         )
 
         self.type_map: Dict[Types, DataType] = type_map_factory(
@@ -168,7 +174,11 @@ class DataTypeManager(_DataTypeManager):
             self.data_type,
         )
 
-    def get_data_int_type(self, types: Types, **kwargs: Any) -> DataType:
+    def get_data_int_type(
+        self,
+        types: Types,
+        **kwargs: Any,
+    ) -> DataType:
         data_type_kwargs: Dict[str, Any] = transform_kwargs(kwargs, number_kwargs)
         strict = StrictTypes.int in self.strict_types
         if data_type_kwargs:
@@ -177,6 +187,16 @@ class DataTypeManager(_DataTypeManager):
                     return self.data_type.from_import(IMPORT_POSITIVE_INT)
                 if data_type_kwargs == {'lt': 0}:
                     return self.data_type.from_import(IMPORT_NEGATIVE_INT)
+                if (
+                    data_type_kwargs == {'ge': 0}
+                    and self.use_non_positive_negative_number_constrained_types
+                ):
+                    return self.data_type.from_import(IMPORT_NON_NEGATIVE_INT)
+                if (
+                    data_type_kwargs == {'le': 0}
+                    and self.use_non_positive_negative_number_constrained_types
+                ):
+                    return self.data_type.from_import(IMPORT_NON_POSITIVE_INT)
             kwargs = {k: int(v) for k, v in data_type_kwargs.items()}
             if strict:
                 kwargs['strict'] = True
@@ -185,7 +205,11 @@ class DataTypeManager(_DataTypeManager):
             return self.strict_type_map[StrictTypes.int]
         return self.type_map[types]
 
-    def get_data_float_type(self, types: Types, **kwargs: Any) -> DataType:
+    def get_data_float_type(
+        self,
+        types: Types,
+        **kwargs: Any,
+    ) -> DataType:
         data_type_kwargs = transform_kwargs(kwargs, number_kwargs)
         strict = StrictTypes.float in self.strict_types
         if data_type_kwargs:
@@ -194,6 +218,16 @@ class DataTypeManager(_DataTypeManager):
                     return self.data_type.from_import(IMPORT_POSITIVE_FLOAT)
                 if data_type_kwargs == {'lt': 0}:
                     return self.data_type.from_import(IMPORT_NEGATIVE_FLOAT)
+                if (
+                    data_type_kwargs == {'ge': 0}
+                    and self.use_non_positive_negative_number_constrained_types
+                ):
+                    return self.data_type.from_import(IMPORT_NON_NEGATIVE_FLOAT)
+                if (
+                    data_type_kwargs == {'le': 0}
+                    and self.use_non_positive_negative_number_constrained_types
+                ):
+                    return self.data_type.from_import(IMPORT_NON_POSITIVE_FLOAT)
             kwargs = {k: float(v) for k, v in data_type_kwargs.items()}
             if strict:
                 kwargs['strict'] = True
@@ -243,7 +277,11 @@ class DataTypeManager(_DataTypeManager):
             return self.strict_type_map[StrictTypes.bytes]
         return self.type_map[types]
 
-    def get_data_type(self, types: Types, **kwargs: Any) -> DataType:
+    def get_data_type(
+        self,
+        types: Types,
+        **kwargs: Any,
+    ) -> DataType:
         if types == Types.string:
             return self.get_data_str_type(types, **kwargs)
         elif types in (Types.int32, Types.int64, Types.integer):
